aboutsummaryrefslogtreecommitdiff
path: root/source/components/debugger
diff options
context:
space:
mode:
Diffstat (limited to 'source/components/debugger')
-rw-r--r--source/components/debugger/dbcmds.c12
-rw-r--r--source/components/debugger/dbdisply.c61
-rw-r--r--source/components/debugger/dbexec.c12
-rw-r--r--source/components/debugger/dbfileio.c7
-rw-r--r--source/components/debugger/dbhistry.c1
-rw-r--r--source/components/debugger/dbinput.c11
-rw-r--r--source/components/debugger/dbnames.c4
-rw-r--r--source/components/debugger/dbstats.c2
-rw-r--r--source/components/debugger/dbutils.c12
-rw-r--r--source/components/debugger/dbxface.c2
10 files changed, 66 insertions, 58 deletions
diff --git a/source/components/debugger/dbcmds.c b/source/components/debugger/dbcmds.c
index 0e9d78d965e4..5cd41781765f 100644
--- a/source/components/debugger/dbcmds.c
+++ b/source/components/debugger/dbcmds.c
@@ -91,7 +91,7 @@ AcpiDbDeviceResources (
*
* RETURN: Pointer to a NS node
*
- * DESCRIPTION: Convert a string to a valid NS pointer. Handles numeric or
+ * DESCRIPTION: Convert a string to a valid NS pointer. Handles numeric or
* alpha strings.
*
******************************************************************************/
@@ -194,13 +194,13 @@ AcpiDbSleep (
goto ErrorExit;
}
- return (Status);
+ return_ACPI_STATUS (Status);
ErrorExit:
ACPI_EXCEPTION ((AE_INFO, Status, "During sleep test"));
- return (Status);
+ return_ACPI_STATUS (Status);
}
@@ -240,7 +240,7 @@ AcpiDbDisplayLocks (
*
* RETURN: None
*
- * DESCRIPTION: Display information about loaded tables. Current
+ * DESCRIPTION: Display information about loaded tables. Current
* implementation displays all loaded tables.
*
******************************************************************************/
@@ -382,7 +382,7 @@ AcpiDbUnloadAcpiTable (
*
* RETURN: None
*
- * DESCRIPTION: Send an ACPI notification. The value specified is sent to the
+ * DESCRIPTION: Send an ACPI notification. The value specified is sent to the
* named object as an ACPI notify.
*
******************************************************************************/
@@ -577,7 +577,7 @@ AcpiDbDisplayTemplate (
DumpBuffer:
AcpiOsPrintf ("\nRaw data buffer:\n");
- AcpiUtDumpBuffer ((UINT8 *) Node->Object->Buffer.Pointer,
+ AcpiUtDebugDumpBuffer ((UINT8 *) Node->Object->Buffer.Pointer,
Node->Object->Buffer.Length,
DB_BYTE_DISPLAY, ACPI_UINT32_MAX);
diff --git a/source/components/debugger/dbexec.c b/source/components/debugger/dbexec.c
index d8ec3d3febfe..1644fc23a5f8 100644
--- a/source/components/debugger/dbexec.c
+++ b/source/components/debugger/dbexec.c
@@ -674,7 +674,7 @@ AcpiDbGetOutstandingAllocations (
*
* RETURN: Status
*
- * DESCRIPTION: Execute a control method. Name is relative to the current
+ * DESCRIPTION: Execute a control method. Name is relative to the current
* scope.
*
******************************************************************************/
@@ -862,8 +862,8 @@ AcpiDbDumpPldBuffer (
{
AcpiOsPrintf ("Converted _PLD buffer does not compare. New:\n");
- AcpiUtDumpBuffer2 (NewBuffer,
- BufferDesc->Buffer.Length, DB_BYTE_DISPLAY);
+ AcpiUtDumpBuffer (NewBuffer,
+ BufferDesc->Buffer.Length, DB_BYTE_DISPLAY, 0);
}
/* First 32-bit dword */
@@ -924,7 +924,7 @@ AcpiDbDumpPldBuffer (
*
* RETURN: None
*
- * DESCRIPTION: Execute a control method. Name is relative to the current
+ * DESCRIPTION: Execute a control method. Name is relative to the current
* scope.
*
******************************************************************************/
@@ -1058,7 +1058,7 @@ AcpiDbExecute (
*
* RETURN: None
*
- * DESCRIPTION: Debugger execute thread. Waits for a command line, then
+ * DESCRIPTION: Debugger execute thread. Waits for a command line, then
* simply dispatches it.
*
******************************************************************************/
@@ -1329,5 +1329,3 @@ CleanupAndExit:
}
#endif /* ACPI_DEBUGGER */
-
-
diff --git a/source/components/debugger/dbfileio.c b/source/components/debugger/dbfileio.c
index 9845ff47e68f..7b0870d1c991 100644
--- a/source/components/debugger/dbfileio.c
+++ b/source/components/debugger/dbfileio.c
@@ -328,9 +328,9 @@ AcpiDbReadTable (
#ifdef ACPI_OBSOLETE_CODE
/* We only support a limited number of table types */
- if (ACPI_STRNCMP ((char *) TableHeader.Signature, DSDT_SIG, 4) &&
- ACPI_STRNCMP ((char *) TableHeader.Signature, PSDT_SIG, 4) &&
- ACPI_STRNCMP ((char *) TableHeader.Signature, SSDT_SIG, 4))
+ if (!ACPI_COMPARE_NAME ((char *) TableHeader.Signature, ACPI_SIG_DSDT) &&
+ !ACPI_COMPARE_NAME ((char *) TableHeader.Signature, ACPI_SIG_PSDT) &&
+ !ACPI_COMPARE_NAME ((char *) TableHeader.Signature, ACPI_SIG_SSDT))
{
AcpiOsPrintf ("Table signature [%4.4s] is invalid or not supported\n",
(char *) TableHeader.Signature);
@@ -588,4 +588,3 @@ AcpiDbGetTableFromFile (
}
#endif /* ACPI_DEBUGGER */
-
diff --git a/source/components/debugger/dbhistry.c b/source/components/debugger/dbhistry.c
index 536b69cdfaab..571ed3f01526 100644
--- a/source/components/debugger/dbhistry.c
+++ b/source/components/debugger/dbhistry.c
@@ -217,4 +217,3 @@ AcpiDbGetFromHistory (
}
#endif /* ACPI_DEBUGGER */
-
diff --git a/source/components/debugger/dbinput.c b/source/components/debugger/dbinput.c
index 2d48171c4a1d..a431ddcba509 100644
--- a/source/components/debugger/dbinput.c
+++ b/source/components/debugger/dbinput.c
@@ -457,7 +457,7 @@ AcpiDbDisplayHelp (
*
* RETURN: Pointer to the start of the next token.
*
- * DESCRIPTION: Command line parsing. Get the next token on the command line
+ * DESCRIPTION: Command line parsing. Get the next token on the command line
*
******************************************************************************/
@@ -610,7 +610,7 @@ AcpiDbGetNextToken (
*
* RETURN: Count of arguments to the command
*
- * DESCRIPTION: Get the next command line from the user. Gets entire line
+ * DESCRIPTION: Get the next command line from the user. Gets entire line
* up to the next newline
*
******************************************************************************/
@@ -1083,7 +1083,7 @@ AcpiDbCommandDispatch (
*
* RETURN: None
*
- * DESCRIPTION: Debugger execute thread. Waits for a command line, then
+ * DESCRIPTION: Debugger execute thread. Waits for a command line, then
* simply dispatches it.
*
******************************************************************************/
@@ -1126,7 +1126,7 @@ AcpiDbExecuteThread (
*
* RETURN: None
*
- * DESCRIPTION: Debugger execute thread. Waits for a command line, then
+ * DESCRIPTION: Debugger execute thread. Waits for a command line, then
* simply dispatches it.
*
******************************************************************************/
@@ -1152,7 +1152,7 @@ AcpiDbSingleThread (
*
* RETURN: None
*
- * DESCRIPTION: Command line execution for the AML debugger. Commands are
+ * DESCRIPTION: Command line execution for the AML debugger. Commands are
* matched and dispatched here.
*
******************************************************************************/
@@ -1231,4 +1231,3 @@ AcpiDbUserCommands (
}
#endif /* ACPI_DEBUGGER */
-
diff --git a/source/components/debugger/dbnames.c b/source/components/debugger/dbnames.c
index 0393e6ba3755..a51c08d2cb98 100644
--- a/source/components/debugger/dbnames.c
+++ b/source/components/debugger/dbnames.c
@@ -208,7 +208,7 @@ ErrorExit:
*
* RETURN: None
*
- * DESCRIPTION: Dump entire namespace or a subtree. Each node is displayed
+ * DESCRIPTION: Dump entire namespace or a subtree. Each node is displayed
* with type and other information.
*
******************************************************************************/
@@ -305,7 +305,7 @@ AcpiDbDumpNamespaceByOwner (
*
* RETURN: Status
*
- * DESCRIPTION: Find a particular name/names within the namespace. Wildcards
+ * DESCRIPTION: Find a particular name/names within the namespace. Wildcards
* are supported -- '?' matches any character.
*
******************************************************************************/
diff --git a/source/components/debugger/dbstats.c b/source/components/debugger/dbstats.c
index 64c847a493ea..9bcc96322ce4 100644
--- a/source/components/debugger/dbstats.c
+++ b/source/components/debugger/dbstats.c
@@ -314,7 +314,7 @@ AcpiDbClassifyOneObject (
AcpiGbl_NodeTypeCount [Type]++;
}
- return AE_OK;
+ return (AE_OK);
#ifdef ACPI_FUTURE_IMPLEMENTATION
diff --git a/source/components/debugger/dbutils.c b/source/components/debugger/dbutils.c
index 36a6d207d920..947dd9d93a7b 100644
--- a/source/components/debugger/dbutils.c
+++ b/source/components/debugger/dbutils.c
@@ -117,7 +117,7 @@ AcpiDbMatchArgument (
*
* RETURN: None
*
- * DESCRIPTION: Set the current destination for debugger output. Also sets
+ * DESCRIPTION: Set the current destination for debugger output. Also sets
* the debug output level accordingly.
*
******************************************************************************/
@@ -204,7 +204,7 @@ AcpiDbDumpExternalObject (
{
AcpiOsPrintf ("\n");
}
- AcpiUtDumpBuffer (ACPI_CAST_PTR (UINT8, ObjDesc->Buffer.Pointer),
+ AcpiUtDebugDumpBuffer (ACPI_CAST_PTR (UINT8, ObjDesc->Buffer.Pointer),
ObjDesc->Buffer.Length, DB_BYTE_DISPLAY, _COMPONENT);
}
else
@@ -316,7 +316,7 @@ AcpiDbPrepNamestring (
*
* DESCRIPTION: Lookup a name in the ACPI namespace
*
- * Note: Currently begins search from the root. Could be enhanced to use
+ * Note: Currently begins search from the root. Could be enhanced to use
* the current prefix (scope) node as the search beginning point.
*
******************************************************************************/
@@ -407,7 +407,7 @@ AcpiDbUint32ToHexString (
*
* RETURN: Status
*
- * DESCRIPTION: Second pass parse of the ACPI tables. We need to wait until
+ * DESCRIPTION: Second pass parse of the ACPI tables. We need to wait until
* second pass to parse the control methods
*
******************************************************************************/
@@ -513,11 +513,9 @@ AcpiDbDumpBuffer (
AcpiOsPrintf ("\nLocation %X:\n", Address);
AcpiDbgLevel |= ACPI_LV_TABLES;
- AcpiUtDumpBuffer (ACPI_TO_POINTER (Address), 64, DB_BYTE_DISPLAY,
+ AcpiUtDebugDumpBuffer (ACPI_TO_POINTER (Address), 64, DB_BYTE_DISPLAY,
ACPI_UINT32_MAX);
}
#endif
#endif /* ACPI_DEBUGGER */
-
-
diff --git a/source/components/debugger/dbxface.c b/source/components/debugger/dbxface.c
index cd3027343459..0a7b9465eb1d 100644
--- a/source/components/debugger/dbxface.c
+++ b/source/components/debugger/dbxface.c
@@ -231,7 +231,7 @@ AcpiDbSingleStep (
switch (OpcodeClass)
{
case AML_CLASS_UNKNOWN:
- case AML_CLASS_ARGUMENT: /* constants, literals, etc. do nothing */
+ case AML_CLASS_ARGUMENT: /* constants, literals, etc. do nothing */
return (AE_OK);
default:
diff --git a/source/components/debugger/dbdisply.c b/source/components/debugger/dbdisply.c
index b58cb1c346fb..a9943a0595a1 100644
--- a/source/components/debugger/dbdisply.c
+++ b/source/components/debugger/dbdisply.c
@@ -176,7 +176,7 @@ AcpiDbDumpParserDescriptor (
*
* FUNCTION: AcpiDbDecodeAndDisplayObject
*
- * PARAMETERS: Target - String with object to be displayed. Names
+ * PARAMETERS: Target - String with object to be displayed. Names
* and hex pointers are supported.
* OutputType - Byte, Word, Dword, or Qword (B|W|D|Q)
*
@@ -270,7 +270,7 @@ AcpiDbDecodeAndDisplayObject (
return;
}
- AcpiUtDumpBuffer (ObjPtr, sizeof (ACPI_OPERAND_OBJECT), Display,
+ AcpiUtDebugDumpBuffer (ObjPtr, sizeof (ACPI_OPERAND_OBJECT), Display,
ACPI_UINT32_MAX);
AcpiExDumpObjectDescriptor (ObjPtr, 1);
break;
@@ -287,7 +287,7 @@ AcpiDbDecodeAndDisplayObject (
return;
}
- AcpiUtDumpBuffer (ObjPtr, sizeof (ACPI_PARSE_OBJECT), Display,
+ AcpiUtDebugDumpBuffer (ObjPtr, sizeof (ACPI_PARSE_OBJECT), Display,
ACPI_UINT32_MAX);
AcpiDbDumpParserDescriptor ((ACPI_PARSE_OBJECT *) ObjPtr);
break;
@@ -305,7 +305,7 @@ AcpiDbDecodeAndDisplayObject (
/* Just dump some memory */
- AcpiUtDumpBuffer (ObjPtr, Size, Display, ACPI_UINT32_MAX);
+ AcpiUtDebugDumpBuffer (ObjPtr, Size, Display, ACPI_UINT32_MAX);
break;
}
@@ -342,7 +342,7 @@ DumpNode:
return;
}
- AcpiUtDumpBuffer ((void *) Node, sizeof (ACPI_NAMESPACE_NODE),
+ AcpiUtDebugDumpBuffer ((void *) Node, sizeof (ACPI_NAMESPACE_NODE),
Display, ACPI_UINT32_MAX);
AcpiExDumpNamespaceNode (Node, 1);
@@ -357,7 +357,7 @@ DumpNode:
return;
}
- AcpiUtDumpBuffer ((void *) ObjDesc, sizeof (ACPI_OPERAND_OBJECT),
+ AcpiUtDebugDumpBuffer ((void *) ObjDesc, sizeof (ACPI_OPERAND_OBJECT),
Display, ACPI_UINT32_MAX);
AcpiExDumpObjectDescriptor (ObjDesc, 1);
}
@@ -643,7 +643,7 @@ AcpiDbDisplayCallingTree (
*
* FUNCTION: AcpiDbDisplayObjectType
*
* PARAMETERS: ObjectArg - User entered NS node handle
*
* RETURN: None
*
@@ -653,17 +653,21 @@ AcpiDbDisplayCallingTree (
void
AcpiDbDisplayObjectType (
- char *ObjectArg)
+ char *Name)
{
- ACPI_HANDLE Handle;
+ ACPI_NAMESPACE_NODE *Node;
ACPI_DEVICE_INFO *Info;
ACPI_STATUS Status;
UINT32 i;
- Handle = ACPI_TO_POINTER (ACPI_STRTOUL (ObjectArg, NULL, 16));
+ Node = AcpiDbConvertToNode (Name);
+ if (!Node)
+ {
+ return;
+ }
- Status = AcpiGetObjectInfo (Handle, &Info);
+ Status = AcpiGetObjectInfo (ACPI_CAST_PTR (ACPI_HANDLE, Node), &Info);
if (ACPI_FAILURE (Status))
{
AcpiOsPrintf ("Could not get object info, %s\n",
@@ -671,18 +675,25 @@ AcpiDbDisplayObjectType (
return;
}
- AcpiOsPrintf ("ADR: %8.8X%8.8X, STA: %8.8X, Flags: %X\n",
- ACPI_FORMAT_UINT64 (Info->Address),
- Info->CurrentStatus, Info->Flags);
-
- AcpiOsPrintf ("S1D-%2.2X S2D-%2.2X S3D-%2.2X S4D-%2.2X\n",
- Info->HighestDstates[0], Info->HighestDstates[1],
- Info->HighestDstates[2], Info->HighestDstates[3]);
-
- AcpiOsPrintf ("S0W-%2.2X S1W-%2.2X S2W-%2.2X S3W-%2.2X S4W-%2.2X\n",
- Info->LowestDstates[0], Info->LowestDstates[1],
- Info->LowestDstates[2], Info->LowestDstates[3],
- Info->LowestDstates[4]);
+ if (Info->Valid & ACPI_VALID_ADR)
+ {
+ AcpiOsPrintf ("ADR: %8.8X%8.8X, STA: %8.8X, Flags: %X\n",
+ ACPI_FORMAT_UINT64 (Info->Address),
+ Info->CurrentStatus, Info->Flags);
+ }
+ if (Info->Valid & ACPI_VALID_SXDS)
+ {
+ AcpiOsPrintf ("S1D-%2.2X S2D-%2.2X S3D-%2.2X S4D-%2.2X\n",
+ Info->HighestDstates[0], Info->HighestDstates[1],
+ Info->HighestDstates[2], Info->HighestDstates[3]);
+ }
+ if (Info->Valid & ACPI_VALID_SXWS)
+ {
+ AcpiOsPrintf ("S0W-%2.2X S1W-%2.2X S2W-%2.2X S3W-%2.2X S4W-%2.2X\n",
+ Info->LowestDstates[0], Info->LowestDstates[1],
+ Info->LowestDstates[2], Info->LowestDstates[3],
+ Info->LowestDstates[4]);
+ }
if (Info->Valid & ACPI_VALID_HID)
{
@@ -692,6 +703,10 @@ AcpiDbDisplayObjectType (
{
AcpiOsPrintf ("UID: %s\n", Info->UniqueId.String);
}
+ if (Info->Valid & ACPI_VALID_SUB)
+ {
+ AcpiOsPrintf ("SUB: %s\n", Info->SubsystemId.String);
+ }
if (Info->Valid & ACPI_VALID_CID)
{
for (i = 0; i < Info->CompatibleIdList.Count; i++)
@@ -643,7 +643,7 @@ AcpiDbDisplayCallingTree (
* FUNCTION: AcpiDbDisplayObjectType
*
- * PARAMETERS: ObjectArg - User entered NS node handle
+ * PARAMETERS: Name - User entered NS node handle or name
*
* RETURN: None